@@ -1,5 +1,5 @@
 
-var deprecate = require('../../..')('new-lib')
+var deprecate = require('../../..')('New-Lib')
 
 exports.old = function () {
   deprecate('old')
