@@ -11,7 +11,7 @@
  * @private
  */
 
-var bufferConcat = require('./buffer-concat')
+var Buffer = require('safe-buffer').Buffer
 
 /**
  * Module exports.
@@ -32,7 +32,7 @@ function captureStderr (fn, color) {
 
   process.stderr.isTTY = Boolean(color)
   process.stderr.write = function write (chunk, encoding) {
-    chunks.push(new Buffer(chunk, encoding))
+    chunks.push(Buffer.from(chunk, encoding))
   }
 
   try {
@@ -42,5 +42,5 @@ function captureStderr (fn, color) {
     process.stderr.write = write
   }
 
-  return bufferConcat(chunks).toString('utf8')
+  return Buffer.concat(chunks).toString('utf8')
 }
