@@ -1,7 +1,6 @@
 
 var assert = require('assert')
 var basename = require('path').basename
-var bufferConcat = require('./support/buffer-concat')
 var captureStderr = require('./support/capture-stderr')
 var depd = require('..')
 var libs = require('./fixtures/libs')
@@ -10,10 +9,11 @@ var path = require('path')
 var script = path.join(__dirname, 'fixtures', 'script.js')
 var spawn = require('child_process').spawn
 var strictlib = libs.strict
+var uid = require('uid-safe').sync
 
 describe('depd(namespace)', function () {
   it('creates deprecated function', function () {
-    assert.equal(typeof depd('test'), 'function')
+    assert.strictEqual(typeof depd('test'), 'function')
   })
 
   it('requires namespace', function () {
@@ -88,8 +88,8 @@ describe('deprecate(message)', function () {
     }
 
     var stderr = captureStderr(callold)
-    assert.equal(stderr.split('deprecated').length, 2)
-    assert.equal(stderr.split('invoke').length, 6)
+    assert.strictEqual(stderr.split('deprecated').length, 2)
+    assert.strictEqual(stderr.split('invoke').length, 6)
   })
 
   it('should warn for different fns on same call site', function () {
@@ -114,8 +114,8 @@ describe('deprecate(message)', function () {
     var stderr = captureStderr(callold)
     var fileline = stderr.match(/\.js:[0-9]+:/)
     assert.ok(stderr.indexOf(basename(__filename)) !== -1)
-    assert.equal(stderr.split('deprecated').length, 3)
-    assert.equal(stderr.split(fileline[0]).length, 3)
+    assert.strictEqual(stderr.split('deprecated').length, 3)
+    assert.strictEqual(stderr.split(fileline[0]).length, 3)
   })
 
   describe('when message omitted', function () {
@@ -222,7 +222,7 @@ describe('deprecate(message)', function () {
     })
 
     it('should log in color', function () {
-      assert.notEqual(stderr, '')
+      assert.notStrictEqual(stderr, '')
       assert.ok(stderr.indexOf('\x1b[') !== -1)
     })
 
@@ -252,7 +252,7 @@ describe('deprecate(message)', function () {
     })
 
     it('should not log in color', function () {
-      assert.notEqual(stderr, '')
+      assert.notStrictEqual(stderr, '')
       assert.ok(stderr.indexOf('\x1b[') === -1)
     })
 
@@ -291,14 +291,14 @@ describe('deprecate.function(fn, message)', function () {
   })
 
   it('should have same arity', function () {
-    assert.equal(mylib.oldfn.length, 2)
+    assert.strictEqual(mylib.oldfn.length, 2)
   })
 
   it('should pass arguments', function () {
     var ret
     function callold () { ret = mylib.oldfn(1, 2) }
     assert.ok(captureStderr(callold).indexOf(' oldfn ') !== -1)
-    assert.equal(ret, 2)
+    assert.strictEqual(ret, 2)
   })
 
   it('should show call site outside scope', function () {
@@ -324,8 +324,8 @@ describe('deprecate.function(fn, message)', function () {
     }
 
     var stderr = captureStderr(callold)
-    assert.equal(stderr.split('deprecated').length, 2)
-    assert.equal(stderr.split('invoke').length, 6)
+    assert.strictEqual(stderr.split('deprecated').length, 2)
+    assert.strictEqual(stderr.split('invoke').length, 6)
   })
 
   it('should handle rapid calling of deprecated thing', function () {
@@ -338,7 +338,7 @@ describe('deprecate.function(fn, message)', function () {
     }
 
     var stderr = captureStderr(callold)
-    assert.equal(stderr.split('deprecated').length, 2)
+    assert.strictEqual(stderr.split('deprecated').length, 2)
   })
 
   it('should warn for different calls on same line', function () {
@@ -349,8 +349,8 @@ describe('deprecate.function(fn, message)', function () {
     var stderr = captureStderr(callold)
     var fileline = stderr.match(/\.js:[0-9]+:/)
     assert.ok(stderr.indexOf(basename(__filename)) !== -1)
-    assert.equal(stderr.split('deprecated').length, 3)
-    assert.equal(stderr.split(fileline[0]).length, 3)
+    assert.strictEqual(stderr.split('deprecated').length, 3)
+    assert.strictEqual(stderr.split(fileline[0]).length, 3)
   })
 
   describe('when message omitted', function () {
@@ -409,7 +409,7 @@ describe('deprecate.property(obj, prop, message)', function () {
   it('should throw when given non-configurable property', function () {
     var deprecate = depd('test')
     var obj = {}
-    Object.defineProperty(obj, 'thing', {value: 'thingie'})
+    Object.defineProperty(obj, 'thing', { value: 'thingie' })
     assert.throws(deprecate.property.bind(deprecate, obj, 'thing'), /property.*configurable/)
   })
 
@@ -428,7 +428,7 @@ describe('deprecate.property(obj, prop, message)', function () {
     assert.ok(stderr.indexOf(' deprecated ') !== -1)
     assert.ok(stderr.indexOf(' propa gone ') !== -1)
     assert.ok(captureStderr(callprop).indexOf(' deprecated ') !== -1)
-    assert.equal(val, 'newval')
+    assert.strictEqual(val, 'newval')
   })
 
   it('should only warn once per call site', function () {
@@ -440,8 +440,8 @@ describe('deprecate.property(obj, prop, message)', function () {
     }
 
     var stderr = captureStderr(callold)
-    assert.equal(stderr.split('deprecated').length, 2)
-    assert.equal(stderr.split('access').length, 6)
+    assert.strictEqual(stderr.split('deprecated').length, 2)
+    assert.strictEqual(stderr.split('access').length, 6)
   })
 
   it('should warn for different accesses on same line', function () {
@@ -452,8 +452,8 @@ describe('deprecate.property(obj, prop, message)', function () {
     var stderr = captureStderr(callold)
     var fileline = stderr.match(/\.js:[0-9]+:/)
     assert.ok(stderr.indexOf(basename(__filename)) !== -1)
-    assert.equal(stderr.split('deprecated').length, 3)
-    assert.equal(stderr.split(fileline[0]).length, 3)
+    assert.strictEqual(stderr.split('deprecated').length, 3)
+    assert.strictEqual(stderr.split(fileline[0]).length, 3)
   })
 
   it('should show call site outside scope', function () {
@@ -514,7 +514,7 @@ describe('deprecate.property(obj, prop, message)', function () {
       function callold () { return mylib.propget }
       function setold () { mylib.propget = 'val' }
       assert.ok(captureStderr(callold).indexOf(' deprecated ') !== -1)
-      assert.equal(captureStderr(setold), '')
+      assert.strictEqual(captureStderr(setold), '')
     })
   })
 
@@ -528,12 +528,12 @@ describe('deprecate.property(obj, prop, message)', function () {
 
     it('should not log on access when no accessor', function () {
       function callold () { return mylib.propsetter }
-      assert.equal(captureStderr(callold), '')
+      assert.strictEqual(captureStderr(callold), '')
     })
 
     it('should not log on set when no setter', function () {
       function callold () { mylib.propgetter = 'val' }
-      assert.equal(captureStderr(callold), '')
+      assert.strictEqual(captureStderr(callold), '')
     })
   })
 
@@ -575,7 +575,7 @@ describe('process.on(\'deprecation\', fn)', function () {
   function ondeprecation (err) { error = err }
 
   it('should not write when listener exists', function () {
-    assert.equal(stderr, '')
+    assert.strictEqual(stderr, '')
   })
 
   it('should emit error', function () {
@@ -583,19 +583,19 @@ describe('process.on(\'deprecation\', fn)', function () {
   })
 
   it('should emit DeprecationError', function () {
-    assert.equal(error.name, 'DeprecationError')
+    assert.strictEqual(error.name, 'DeprecationError')
   })
 
   it('should emit error with message', function () {
-    assert.equal(error.message, 'old')
+    assert.strictEqual(error.message, 'old')
   })
 
   it('should emit error with namespace', function () {
-    assert.equal(error.namespace, 'my-lib')
+    assert.strictEqual(error.namespace, 'my-lib')
   })
 
   it('should emit error with proper [[Class]]', function () {
-    assert.equal(Object.prototype.toString.call(error), '[object Error]')
+    assert.strictEqual(Object.prototype.toString.call(error), '[object Error]')
   })
 
   it('should be instanceof Error', function () {
@@ -604,17 +604,17 @@ describe('process.on(\'deprecation\', fn)', function () {
 
   it('should emit error with proper stack', function () {
     var stack = error.stack.split('\n')
-    assert.equal(stack[0], 'DeprecationError: my-lib deprecated old')
+    assert.strictEqual(stack[0], 'DeprecationError: my-lib deprecated old')
     assert.ok(/ {4}at callold \(.+test\.js:[0-9]+:[0-9]+\)/.test(stack[1]))
   })
 
   it('should have writable properties', function () {
     error.name = 'bname'
-    assert.equal(error.name, 'bname')
+    assert.strictEqual(error.name, 'bname')
     error.message = 'bmessage'
-    assert.equal(error.message, 'bmessage')
+    assert.strictEqual(error.message, 'bmessage')
     error.stack = 'bstack'
-    assert.equal(error.stack, 'bstack')
+    assert.strictEqual(error.stack, 'bstack')
   })
 })
 
@@ -637,37 +637,37 @@ describe('process.env.NO_DEPRECATION', function () {
   it('should suppress given namespace', function () {
     process.env.NO_DEPRECATION = 'old-lib'
     var oldlib = libs.old
-    assert.equal(captureStderr(oldlib.old), '')
-    assert.notEqual(captureStderr(oldlib.old2), '')
+    assert.strictEqual(captureStderr(oldlib.old), '')
+    assert.notStrictEqual(captureStderr(oldlib.old2), '')
   })
 
   it('should suppress multiple namespaces', function () {
     process.env.NO_DEPRECATION = 'cool-lib,neat-lib'
     var coollib = libs.cool
-    assert.equal(captureStderr(coollib.cool), '')
-    assert.equal(captureStderr(coollib.neat), '')
+    assert.strictEqual(captureStderr(coollib.cool), '')
+    assert.strictEqual(captureStderr(coollib.neat), '')
   })
 
   it('should be case-insensitive', function () {
     process.env.NO_DEPRECATION = 'NEW-LIB'
     var newlib = libs.new
-    assert.equal(captureStderr(newlib.old), '')
+    assert.strictEqual(captureStderr(newlib.old), '')
   })
 
   it('should emit "deprecation" events anyway', function () {
     process.env.NO_DEPRECATION = 'thing-lib'
     var thinglib = libs.thing
     process.on('deprecation', ondeprecation)
-    assert.equal(captureStderr(thinglib.old), '')
-    assert.equal(error.namespace, 'thing-lib')
+    assert.strictEqual(captureStderr(thinglib.old), '')
+    assert.strictEqual(error.namespace, 'thing-lib')
   })
 
   describe('when *', function () {
     it('should suppress any namespace', function () {
       process.env.NO_DEPRECATION = '*'
       var multilib = libs.multi
-      assert.equal(captureStderr(multilib.old), '')
-      assert.equal(captureStderr(multilib.old2), '')
+      assert.strictEqual(captureStderr(multilib.old), '')
+      assert.strictEqual(captureStderr(multilib.old2), '')
     })
   })
 })
@@ -702,7 +702,7 @@ describe('process.env.TRACE_DEPRECATION', function () {
     })
 
     it('should log in color', function () {
-      assert.notEqual(stderr, '')
+      assert.notStrictEqual(stderr, '')
       assert.ok(stderr.indexOf('\x1b[') !== -1)
     })
 
@@ -719,10 +719,10 @@ describe('process.env.TRACE_DEPRECATION', function () {
 
 describe('node script.js', function () {
   it('should display deprecation message', function (done) {
-    captureChildStderr([script], function (err, stderr) {
+    captureChildStderr(script, [], function (err, stderr) {
       if (err) return done(err)
       var filename = path.relative(process.cwd(), script)
-      assert.equal(stderr, '__timestamp__ my-cool-module deprecated oldfunction at ' + filename + ':7:10\n')
+      assert.strictEqual(stderr, '__timestamp__ my-cool-module deprecated oldfunction at ' + filename + ':7:10\n')
       done()
     })
   })
@@ -737,9 +737,9 @@ describe('node script.js', function () {
 
   describe('node --no-deprecation script.js', function () {
     it('should suppress deprecation message', function (done) {
-      captureChildStderr(['--no-deprecation', script], function (err, stderr) {
+      captureChildStderr(script, ['--no-deprecation'], function (err, stderr) {
         if (err) return done(err)
-        assert.equal(stderr, '')
+        assert.strictEqual(stderr, '')
         done()
       })
     })
@@ -747,7 +747,7 @@ describe('node script.js', function () {
 
   describe('node --trace-deprecation script.js', function () {
     it('should suppress deprecation message', function (done) {
-      captureChildStderr(['--trace-deprecation', script], function (err, stderr) {
+      captureChildStderr(script, ['--trace-deprecation'], function (err, stderr) {
         if (err) return done(err)
         assert.ok(stderr.indexOf('__timestamp__ my-cool-module deprecated oldfunction\n    at run (' + script + ':7:10)\n    at') === 0)
         done()
@@ -756,10 +756,16 @@ describe('node script.js', function () {
   })
 }())
 
-function captureChildStderr (args, callback) {
+function captureChildStderr (script, opts, callback) {
   var chunks = []
-  var env = {PATH: process.env.PATH}
+  var env = { PATH: process.env.PATH }
   var exec = process.execPath
+
+  var args = process.env.running_under_istanbul
+    ? opts.concat(path.join(__dirname, '..', 'node_modules', 'istanbul', 'lib', 'cli.js'),
+      'cover', '--dir=./coverage/child-' + uid(8), '--print=none', script)
+    : opts.concat(script)
+
   var proc = spawn(exec, args, {
     env: env
   })
@@ -771,7 +777,7 @@ function captureChildStderr (args, callback) {
 
   proc.on('error', callback)
   proc.on('exit', function () {
-    var stderr = bufferConcat(chunks)
+    var stderr = Buffer.concat(chunks)
       .toString('utf8')
       .replace(/\w+, \d+ \w+ \d+ \d+:\d+:\d+ \w+/, '__timestamp__')
     callback(null, stderr)
